@@ -106,9 +106,10 @@ int main(int argc, char **argv)
     QQmlApplicationEngine engine;
 
     KDeclarative::KDeclarative kdeclarative;
-    kdeclarative.setDeclarativeEngine(qobject_cast<QQmlEngine *>(&engine));
+    kdeclarative.setDeclarativeEngine(&engine);
     kdeclarative.setTranslationDomain(QStringLiteral("cuttlefish"));
-    kdeclarative.setupBindings();
+    kdeclarative.setupContext();
+    kdeclarative.setupEngine(&engine);
 
     auto package = KPackage::PackageLoader::self()->loadPackage("Plasma/Generic");
     package.setPath("org.kde.plasma.cuttlefish");
@@ -118,14 +119,20 @@ int main(int argc, char **argv)
         return -1;
     }
 
-    engine.load(QUrl::fromLocalFile(package.filePath("mainscript")));
-    if (engine.rootObjects().isEmpty())
-        return -1;
-
     auto iconModel = new CuttleFish::IconModel(engine.rootContext());
     engine.rootContext()->setContextProperty("iconModel", iconModel);
     engine.rootContext()->setContextProperty("pickerMode", parser.isSet("picker"));
+
+    engine.load(QUrl::fromLocalFile(package.filePath("mainscript")));
+    if (engine.rootObjects().isEmpty()) {
+        return -1;
+    }
+
+#if QT_VERSION < QT_VERSION_CHECK(5, 14, 0)
     qmlRegisterType<CuttleFish::IconModel>();
+#else
+    qmlRegisterAnonymousType<CuttleFish::IconModel>("org.kde.plasma.sdk", 1);
+#endif
 
     return app.exec();
 }
