@@ -56,6 +56,10 @@ public:
         }
     }
 
+    int screenForContainment(const Plasma::Containment *containment) const override {
+        return 0;
+    }
+
 private:
     View *m_view;
 };
@@ -73,6 +77,14 @@ View::~View()
 {
 }
 
+void View::resizeEvent(QResizeEvent *event)
+{
+    emit corona()->screenGeometryChanged(0);
+    emit corona()->availableScreenRectChanged();
+    emit corona()->availableScreenRegionChanged();
+    PlasmaQuick::ContainmentView::resizeEvent(event);
+}
+
 QString View::pluginFromPath(const QString &path) const
 {
     QDir dir(path);
