@@ -59,15 +59,15 @@ public:
         FrameSvgPrefixes
     };
 
-    explicit ThemeModel(const KPackage::Package &package, QObject *parent = 0);
-    ~ThemeModel();
+    explicit ThemeModel(const KPackage::Package &package, QObject *parent = nullptr);
+    ~ThemeModel() override;
 
     ThemeListModel *themeList();
     ColorEditor *colorEditor();
 
-    virtual QHash<int, QByteArray> roleNames() const;
-    virtual int rowCount(const QModelIndex &parent) const;
-    virtual QVariant data(const QModelIndex &index, int role) const;
+    QHash<int, QByteArray> roleNames() const override;
+    int rowCount(const QModelIndex &parent) const override;
+    QVariant data(const QModelIndex &index, int role) const override;
 
     void setTheme(const QString &theme);
     QString theme() const;
